# BillingAccountSpendRow

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**amount** | [**Decimal**](Decimal.md) |  | 
**description** | **str** |  | 
**project_id** | **str** |  | 
**quantity** | **float** |  | 
**unit** | [**Unit**](Unit.md) |  | 
**unit_amount** | [**Decimal**](Decimal.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


